package ch.rakudave.jnetmap.view.components;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.Frame;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.BorderFactory;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JEditorPane;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTabbedPane;
import javax.swing.event.HyperlinkEvent;
import javax.swing.event.HyperlinkEvent.EventType;
import javax.swing.event.HyperlinkListener;

import ch.rakudave.jnetmap.controller.Actions;
import ch.rakudave.jnetmap.controller.Controller;
import ch.rakudave.jnetmap.util.Icons;
import ch.rakudave.jnetmap.util.Lang;
import ch.rakudave.jnetmap.util.SwingHelper;

@SuppressWarnings("serial")
public class AboutDialog extends JDialog implements HyperlinkListener {
	
	public AboutDialog(final Frame owner) {
		super(owner, Lang.getNoHTML("about"), ModalityType.DOCUMENT_MODAL);
		setLayout(new BorderLayout(5, 5));
		setMinimumSize(new Dimension(440, 600));
		setPreferredSize(new Dimension(440, 600));
		JLabel jNetMap = new JLabel("Version "+Controller.version, new ImageIcon(this.getClass().getResource("/img/splash-tb.png")), JLabel.CENTER);
			jNetMap.setVerticalTextPosition(JLabel.BOTTOM);
			jNetMap.setHorizontalTextPosition(JLabel.CENTER);
		JEditorPane by = SwingHelper.createHtmlLabel(contributors);
			by.setBorder(BorderFactory.createEmptyBorder(5, 5, 0, 0));
		JEditorPane gpl = SwingHelper.createHtmlLabel(license);
			gpl.setBorder(BorderFactory.createEmptyBorder(5, 5, 0, 0));
			gpl.addHyperlinkListener(this);
		JEditorPane art = SwingHelper.createHtmlLabel(artwork);
			art.setBorder(BorderFactory.createEmptyBorder(5, 5, 0, 0));
			art.addHyperlinkListener(this);
		JEditorPane libs = SwingHelper.createHtmlLabel(usedlibs);
			libs.setBorder(BorderFactory.createEmptyBorder(5, 5, 0, 0));	
		JTabbedPane tp = new JTabbedPane();
		tp.add("Credits", by);
		tp.add("License", gpl);
		tp.add("Artwork", art);
		tp.add("Libraries", libs);
		JPanel bottomRow = new JPanel(new FlowLayout(FlowLayout.CENTER, 5, 5));
			JButton ok = new JButton(Lang.get("action.ok"), Icons.get("ok"));
				ok.addActionListener(new ActionListener() {
					@Override
					public void actionPerformed(ActionEvent e) {
						AboutDialog.this.dispose();
					}
				});
			bottomRow.add(ok);
		add(jNetMap, BorderLayout.NORTH);
		add(tp, BorderLayout.CENTER);
		add(bottomRow, BorderLayout.SOUTH);
		pack();
		SwingHelper.centerTo(owner, this);
		setVisible(true);
	}

	private static final String contributors = "<table width=\"100%\">"
			+ "<tr><b>Development:</b></tr>"
			+ "<tr><td>Lead Developer:</td><td>rakudave</td></tr>"
			+ "<tr><td>Dev, Testing:</td><td>sebehuber</td></tr>"
			+ "<tr></tr>"
			+ "<tr><b>Translation:</b></tr>"
			+ "<tr><td>Arabic:</td><td>Arick McNiel-Chov, Zeki Abdulaali</td></tr>"
			+ "<tr><td></td><td>and Samuel K. Michael</td></tr>"
			+ "<tr><td>English, German:</td><td>rakudave</td></tr>"
			+ "<tr><td>Hungarian:</td><td>Zoltan Fekete</td></tr>"
			+ "<tr><td>Portuguese:</td><td>Delton Giacomozzi</td></tr>"
			+ "<tr><td>Spanish:</td><td>Lenny Qebian</td></tr>"
			+ "</table>";

	private static final String license = "<br>This program is free software; you can redistribute it and/or modify "
			+ "it under the terms of the GNU General Public License as published by "
			+ "the Free Software Foundation; either version 3 of the License, or "
			+ "(at your option) any later version.<br><br>"
			+ "This program is distributed in the hope that it will be useful, "
			+ "but WITHOUT ANY WARRANTY; without even the implied warranty of "
			+ "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the "
			+ "GNU General Public License for more details:<br><a href=\"http://www.gnu.org/licenses/gpl.html\">www.gnu.org/licenses/gpl.html</a>";

	private static final String usedlibs = "<table width=\"100%\">"
			+ "<tr><td>JUNG2</td><td>(Graph framework)</td><td>BSD</td></tr>"
			+ "<tr><td>xstream</td><td>(XML serialisation)</td><td>BSD</td></tr>"
			+ "<tr><td>jspf</td><td>(plugin framework)</td><td>Apache</td></tr>"
			+ "<tr><td>snmp4j</td><td>(SNMP for Java)</td><td>Apache</td></tr>"
			+ "<tr><td>junit</td><td>(Unit tests)</td><td>BSD</td></tr>"
			+ "<tr><td>mail</td><td>(JavaMail)</td><td>Sun Microsystems</td></tr>"
			+ "<tr><td>getopt</td><td>(GNU getopt port)</td><td>GPLv2</td></tr>"
			+ "</table>";

	private static final String artwork = "<table width=\"100%\">"
			+ "<tr><td><b>Icons</b></td><td></td></tr>"
			+ "<tr><td>Elementary</td><td><a href=\"http://danrabbit.deviantart.com/art/elementary-Icons-65437279\">DanRabbit</a></td></tr>"
			+ "<tr><td>Human</td><td><a href=\"http://ubuntu.com\">Ubuntu</a></td></tr>"
			+ "<tr><td>Symbolize</td><td><a href=\"http://dryicons.com/free-icons/preview/symbolize-icons-set\">DryIcons</a></td></tr>"
			+ "<tr><td>Tango</td><td><a href=\"http://tango.freedesktop.org/Tango_Icon_Library\">Tango Project</a></td></tr>"
			+ "<tr><td></td><td></td></tr>"
			+ "<tr><td><b>Devices</b></td><td></td></tr>"
			+ "<tr><td>Cisco</td><td><a href=\"http://www.cisco.com/web/about/ac50/ac47/2.html\">cisco inc.</a></td></tr>"
			+ "<tr><td>Human-o2</td><td><a href=\"http://schollidesign.deviantart.com/art/Human-O2-Iconset-105344123\">Oliver Scholtz</a></td></tr>"
			+ "<tr><td>Reflection</td><td><a href=\"http://www.webdesignerdepot.com/2010/07/200-exclusive-free-icons-reflection\">webdesignerdepot</a></td></tr>"
			+ "</table>";

	@Override
	public void hyperlinkUpdate(HyperlinkEvent e) {
		if (e.getEventType() == EventType.ACTIVATED) {
			Actions.openWebsite(e.getDescription()); //don't ask me why getURL() doesn't work
		}
	}
}
